data {
  int<lower=1> H;
  int<lower=1> n[H];
  int<lower=0> r[H];
  vector<lower=0,upper=1>[H] pi_ex;
}
transformed data {
  vector[H] lpi_ex;
  vector[H] lpi_nex;

  for(h in 1:H) {
    lpi_ex[h]  <-   log(pi_ex[h]);
    lpi_nex[h] <- log1m(pi_ex[h]);
  }
}
parameters {
  vector[H] eta;
  real mu;
  vector[H] theta_nex;
  real<lower=0> tau;
}
transformed parameters {
  vector[H] theta_ex;
  vector[H] lp;
  matrix[H,2] lp_terms;

  theta_ex <- mu + tau * eta;

  for(h in 1:H) {
    // log-lik per mixture component for each data item
    lp_terms[h,1] <- lpi_ex[h]  + binomial_logit_log(r[h], n[h], theta_ex[h]);
    lp_terms[h,2] <- lpi_nex[h] + binomial_logit_log(r[h], n[h], theta_nex[h]);
    // log-lik for data item h given by the sum on the natural scale
    lp[h] <- log_sum_exp(lp_terms[h]);
  }
}
model {
  increment_log_prob(lp);

  mu ~ normal(0, 2);
  theta_nex ~ normal(0, 2);

  tau ~ normal(0, 1);

  eta ~ normal(0, 1);
}
generated quantities {
  vector[H] post_p_ex;
  vector[H] theta;

  for(h in 1:H) {
    post_p_ex[h] <- exp(lp_terms[h,1] - lp[h]);
    theta[h] <-  post_p_ex[h] * theta_ex[h] + (1-post_p_ex[h]) * theta_nex[h];
  }
}
